@@ -13,6 +13,26 @@ from ...tools.moments import calc_2nd_moment
 
 
 class velocity:
+    """The class that computes RNA/protein velocity given unknown parameters.
+
+     Arguments
+     ---------
+         alpha: :class:`~numpy.ndarray`
+             A matrix of transcription rate.
+         beta: :class:`~numpy.ndarray`
+             A vector of splicing rate constant for each gene.
+         gamma: :class:`~numpy.ndarray`
+             A vector of spliced mRNA degradation rate constant for each gene.
+         eta: :class:`~numpy.ndarray`
+             A vector of protein synthesis rate constant for each gene.
+         delta: :class:`~numpy.ndarray`
+             A vector of protein degradation rate constant for each gene.
+         t: :class:`~numpy.ndarray` or None (default: None)
+             A vector of the measured time points for cells
+         estimation: :class:`~ss_estimation`
+             An instance of the estimation class. If this not None, the parameters will be taken from this class instead of the input arguments.
+     """
+
     def __init__(
         self,
         alpha=None,
@@ -23,25 +43,6 @@ class velocity:
         t=None,
         estimation=None,
     ):
-        """The class that computes RNA/protein velocity given unknown parameters.
-
-        Arguments
-        ---------
-        alpha: :class:`~numpy.ndarray`
-            A matrix of transcription rate.
-        beta: :class:`~numpy.ndarray`
-            A vector of splicing rate constant for each gene.
-        gamma: :class:`~numpy.ndarray`
-            A vector of spliced mRNA degradation rate constant for each gene.
-        eta: :class:`~numpy.ndarray`
-            A vector of protein synthesis rate constant for each gene.
-        delta: :class:`~numpy.ndarray`
-            A vector of protein degradation rate constant for each gene.
-        t: :class:`~numpy.ndarray` or None (default: None)
-            A vector of the measured time points for cells
-        estimation: :class:`~ss_estimation`
-            An instance of the estimation class. If this not None, the parameters will be taken from this class instead of the input arguments.
-        """
         if estimation is not None:
             self.parameters = {}
             self.parameters["alpha"] = estimation.parameters["alpha"]
@@ -65,13 +66,13 @@ class velocity:
 
         Arguments
         ---------
-        U: :class:`~numpy.ndarray` or sparse `csr_matrix`
-            A matrix of unspliced mRNA count. Dimension: genes x cells.
+            U: :class:`~numpy.ndarray` or sparse `csr_matrix`
+                A matrix of unspliced mRNA count. Dimension: genes x cells.
 
         Returns
         -------
-        V: :class:`~numpy.ndarray` or sparse `csr_matrix`
-            Each column of V is a velocity vector for the corresponding cell. Dimension: genes x cells.
+            V: :class:`~numpy.ndarray` or sparse `csr_matrix`
+                Each column of V is a velocity vector for the corresponding cell. Dimension: genes x cells.
         """
 
         t = self.parameters["t"]
@@ -151,15 +152,15 @@ class velocity:
 
         Arguments
         ---------
-        U: :class:`~numpy.ndarray` or sparse `csr_matrix`
-            A matrix of unspliced mRNA counts. Dimension: genes x cells.
-        S: :class:`~numpy.ndarray` or sparse `csr_matrix`
-            A matrix of spliced mRNA counts. Dimension: genes x cells.
+            U: :class:`~numpy.ndarray` or sparse `csr_matrix`
+                A matrix of unspliced mRNA counts. Dimension: genes x cells.
+            S: :class:`~numpy.ndarray` or sparse `csr_matrix`
+                A matrix of spliced mRNA counts. Dimension: genes x cells.
 
         Returns
         -------
-        V: :class:`~numpy.ndarray` or sparse `csr_matrix`
-            Each column of V is a velocity vector for the corresponding cell. Dimension: genes x cells.
+            V: :class:`~numpy.ndarray` or sparse `csr_matrix`
+                Each column of V is a velocity vector for the corresponding cell. Dimension: genes x cells.
         """
 
         t = self.parameters["t"]
@@ -224,15 +225,15 @@ class velocity:
 
         Arguments
         ---------
-        S: :class:`~numpy.ndarray` or sparse `csr_matrix`
-            A matrix of spliced mRNA counts. Dimension: genes x cells.
-        P: :class:`~numpy.ndarray` or sparse `csr_matrix`
-            A matrix of protein counts. Dimension: genes x cells.
+            S: :class:`~numpy.ndarray` or sparse `csr_matrix`
+                A matrix of spliced mRNA counts. Dimension: genes x cells.
+            P: :class:`~numpy.ndarray` or sparse `csr_matrix`
+                A matrix of protein counts. Dimension: genes x cells.
 
         Returns
         -------
-        V: :class:`~numpy.ndarray` or sparse `csr_matrix`
-            Each column of V is a velocity vector for the corresponding cell. Dimension: genes x cells.
+            V: :class:`~numpy.ndarray` or sparse `csr_matrix`
+                Each column of V is a velocity vector for the corresponding cell. Dimension: genes x cells.
         """
 
         t = self.parameters["t"]
@@ -284,8 +285,8 @@ class velocity:
 
         Returns
         -------
-        n_cells: int
-            The second dimension of the alpha matrix, if alpha is given.
+            n_cells: int
+                The second dimension of the alpha matrix, if alpha is given.
         """
         if self.parameters["alpha"] is not None:
             n_cells = self.parameters["alpha"].shape[1]
@@ -298,8 +299,8 @@ class velocity:
 
         Returns
         -------
-        n_genes: int
-            The first dimension of the alpha matrix, if alpha is given. Or, the length of beta, gamma, eta, or delta, if they are given.
+            n_genes: int
+                The first dimension of the alpha matrix, if alpha is given. Or, the length of beta, gamma, eta, or delta, if they are given.
         """
         if self.parameters["alpha"] is not None:
             n_genes = self.parameters["alpha"].shape[0]
@@ -317,31 +318,10 @@ class velocity:
 
 
 class ss_estimation:
-    def __init__(
-        self,
-        U=None,
-        Ul=None,
-        S=None,
-        Sl=None,
-        P=None,
-        US=None,
-        S2=None,
-        conn=None,
-        t=None,
-        ind_for_proteins=None,
-        model='stochastic',
-        est_method='gmm',
-        experiment_type="deg",
-        assumption_mRNA=None,
-        assumption_protein="ss",
-        concat_data=True,
-        cores=1,
-        **kwargs
-    ):
-        """The class that estimates parameters with input data.
+    """The class that estimates parameters with input data.
 
-        Arguments
-        ---------
+    Arguments
+    ---------
         U: :class:`~numpy.ndarray` or sparse `csr_matrix`
             A matrix of unspliced mRNA count.
         Ul: :class:`~numpy.ndarray` or sparse `csr_matrix`
@@ -364,17 +344,17 @@ class ss_estimation:
             A 1-D vector of the indices in the U, Ul, S, Sl layers that corresponds to the row name in the `protein` or
             `X_protein` key of `.obsm` attribute.
         experiment_type: str
-            labelling experiment type. Available options are: 
-            (1) 'deg': degradation experiment; 
-            (2) 'kin': synthesis experiment; 
+            labelling experiment type. Available options are:
+            (1) 'deg': degradation experiment;
+            (2) 'kin': synthesis experiment;
             (3) 'one-shot': one-shot kinetic experiment;
             (4) 'mix_std_stm': a mixed steady state and stimulation labeling experiment.
         assumption_mRNA: str
-            Parameter estimation assumption for mRNA. Available options are: 
-            (1) 'ss': pseudo steady state; 
-            (2) None: kinetic data with no assumption. 
+            Parameter estimation assumption for mRNA. Available options are:
+            (1) 'ss': pseudo steady state;
+            (2) None: kinetic data with no assumption.
         assumption_protein: str
-            Parameter estimation assumption for protein. Available options are: 
+            Parameter estimation assumption for protein. Available options are:
             (1) 'ss': pseudo steady state;
         concat_data: bool (default: True)
             Whether to concatenate data
@@ -382,8 +362,8 @@ class ss_estimation:
             Number of cores to run the estimation. If cores is set to be > 1, multiprocessing will be used to parallel
             the parameter estimation.
 
-        Attributes
-        ----------
+    Returns
+    ----------
         t: :class:`~ss_estimation`
             A vector of time points.
         data: `dict`
@@ -401,7 +381,30 @@ class ss_estimation:
                 gamma: spliced mRNA degradation rate
                 eta: translation rate
                 delta: protein degradation rate
-        """
+    """
+
+    def __init__(
+        self,
+        U=None,
+        Ul=None,
+        S=None,
+        Sl=None,
+        P=None,
+        US=None,
+        S2=None,
+        conn=None,
+        t=None,
+        ind_for_proteins=None,
+        model='stochastic',
+        est_method='gmm',
+        experiment_type="deg",
+        assumption_mRNA=None,
+        assumption_protein="ss",
+        concat_data=True,
+        cores=1,
+        **kwargs
+    ):
+
         self.t = t
         self.data = {"uu": U, "ul": Ul, "su": S, "sl": Sl, "p": P, "us": US, "s2": S2}
         if concat_data:
@@ -454,16 +457,16 @@ class ss_estimation:
 
         Arguments
         ---------
-        intercept: `bool`
-            If using steady state assumption for fitting, then:
-            True -- the linear regression is performed with an unfixed intercept;
-            False -- the linear regression is performed with a fixed zero intercept.
-        perc_left: `float` (default: 5)
-            The percentage of samples included in the linear regression in the left tail. If set to None, then all the samples are included.
-        perc_right: `float` (default: 5)
-            The percentage of samples included in the linear regression in the right tail. If set to None, then all the samples are included.
-        clusters: `list`
-            A list of n clusters, each element is a list of indices of the samples which belong to this cluster.
+            intercept: `bool`
+                If using steady state assumption for fitting, then:
+                True -- the linear regression is performed with an unfixed intercept;
+                False -- the linear regression is performed with a fixed zero intercept.
+            perc_left: `float` (default: 5)
+                The percentage of samples included in the linear regression in the left tail. If set to None, then all the samples are included.
+            perc_right: `float` (default: 5)
+                The percentage of samples included in the linear regression in the right tail. If set to None, then all the samples are included.
+            clusters: `list`
+                A list of n clusters, each element is a list of indices of the samples which belong to this cluster.
         """
         n = self.get_n_genes()
         cores = max(1, int(self.cores))
@@ -573,10 +576,10 @@ class ss_estimation:
                         if self.data["sl"] is None
                         else self.data["su"] + self.data["sl"]
                     )
-                    US = self.data['us'] if 'us' in self.data.keys() else calc_2nd_moment(
+                    US = self.data['us'] if self.data['us'] is not None else calc_2nd_moment(
                         U.T, S.T, self.conn, mX=U.T, mY=S.T
                     ).T
-                    S2 = self.data['s2'] if 's2' in self.data.keys() else calc_2nd_moment(
+                    S2 = self.data['s2'] if self.data['s2'] is not None else calc_2nd_moment(
                         S.T, S.T, self.conn, mX=S.T, mY=S.T
                     ).T
                     if cores == 1:
@@ -624,10 +627,10 @@ class ss_estimation:
                     )
                     U = self.data["ul"]
                     S = self.data["uu"] + self.data["ul"]
-                    US = self.data['us'] if 'us' in self.data.keys() else calc_2nd_moment(
+                    US = self.data['us'] if self.data['us'] is not None else calc_2nd_moment(
                         U.T, S.T, self.conn, mX=U.T, mY=S.T
                     ).T
-                    S2 = self.data['s2'] if 's2' in self.data.keys() else calc_2nd_moment(
+                    S2 = self.data['s2'] if self.data['s2'] is not None else calc_2nd_moment(
                         S.T, S.T, self.conn, mX=S.T, mY=S.T
                     ).T
                     if cores == 1:
@@ -968,10 +971,10 @@ class ss_estimation:
                         )
                         U = self.data["uu"]
                         S = self.data["uu"] + self.data["ul"]
-                        US = self.data['us'] if 'us' in self.data.keys() else calc_2nd_moment(
+                        US = self.data['us'] if self.data['us'] is not None else calc_2nd_moment(
                             U.T, S.T, self.conn, mX=U.T, mY=S.T
                         ).T
-                        S2 = self.data['s2'] if 's2' in self.data.keys() else calc_2nd_moment(
+                        S2 = self.data['s2'] if self.data['s2'] is not None else calc_2nd_moment(
                             S.T, S.T, self.conn, mX=S.T, mY=S.T
                         ).T
                         if cores == 1:
@@ -1011,10 +1014,10 @@ class ss_estimation:
 
                         U = self.data["uu"] + self.data["ul"]
                         S = U + self.data["su"] + self.data["sl"]
-                        US = self.data['us'] if 'us' in self.data.keys() else calc_2nd_moment(
+                        US = self.data['us'] if self.data['us'] is not None else calc_2nd_moment(
                             U.T, S.T, self.conn, mX=U.T, mY=S.T
                         ).T
-                        S2 = self.data['s2'] if 's2' in self.data.keys() else calc_2nd_moment(
+                        S2 = self.data['s2'] if self.data['s2'] is not None else calc_2nd_moment(
                             S.T, S.T, self.conn, mX=S.T, mY=S.T
                         ).T
                         if cores == 1:
@@ -1066,10 +1069,10 @@ class ss_estimation:
                         )
                         U = self.data["ul"]
                         S = self.data["ul"] + self.data["uu"]
-                        US = self.data['us'] if 'us' in self.data.keys() else calc_2nd_moment(
+                        US = self.data['us'] if self.data['us'] is not None else calc_2nd_moment(
                             U.T, S.T, self.conn, mX=U.T, mY=S.T
                         ).T
-                        S2 = self.data['s2'] if 's2' in self.data.keys() else calc_2nd_moment(
+                        S2 = self.data['s2'] if self.data['s2'] is not None else calc_2nd_moment(
                             S.T, S.T, self.conn, mX=S.T, mY=S.T
                         ).T
                         if cores == 1:
@@ -1248,35 +1251,35 @@ class ss_estimation:
 
         Arguments
         ---------
-        u: :class:`~numpy.ndarray` or sparse `csr_matrix`
-            A matrix of unspliced mRNA counts. Dimension: genes x cells.
-        s: :class:`~numpy.ndarray` or sparse `csr_matrix`
-            A matrix of spliced mRNA counts. Dimension: genes x cells.
-        intercept: bool
-            If using steady state assumption for fitting, then:
-            True -- the linear regression is performed with an unfixed intercept;
-            False -- the linear regresssion is performed with a fixed zero intercept.
-        perc_left: float
-            The percentage of samples included in the linear regression in the left tail. If set to None, then all the
-            left samples are excluded.
-        perc_right: float
-            The percentage of samples included in the linear regression in the right tail. If set to None, then all the
-            samples are included.
-        normalize: bool
-            Whether to first normalize the
+            u: :class:`~numpy.ndarray` or sparse `csr_matrix`
+                A matrix of unspliced mRNA counts. Dimension: genes x cells.
+            s: :class:`~numpy.ndarray` or sparse `csr_matrix`
+                A matrix of spliced mRNA counts. Dimension: genes x cells.
+            intercept: bool
+                If using steady state assumption for fitting, then:
+                True -- the linear regression is performed with an unfixed intercept;
+                False -- the linear regresssion is performed with a fixed zero intercept.
+            perc_left: float
+                The percentage of samples included in the linear regression in the left tail. If set to None, then all the
+                left samples are excluded.
+            perc_right: float
+                The percentage of samples included in the linear regression in the right tail. If set to None, then all the
+                samples are included.
+            normalize: bool
+                Whether to first normalize the
 
         Returns
         -------
-        k: float
-            The slope of the linear regression model, which is gamma under the steady state assumption.
-        b: float
-            The intercept of the linear regression model.
-        r2: float
-            Coefficient of determination or r square for the extreme data points.
-        r2: float
-            Coefficient of determination or r square for the extreme data points.
-        all_r2: float
-            Coefficient of determination or r square for all data points.
+            k: float
+                The slope of the linear regression model, which is gamma under the steady state assumption.
+            b: float
+                The intercept of the linear regression model.
+            r2: float
+                Coefficient of determination or r square for the extreme data points.
+            r2: float
+                Coefficient of determination or r square for the extreme data points.
+            all_r2: float
+                Coefficient of determination or r square for all data points.
         """
         if intercept and perc_left is None:
             perc_left = perc_right
@@ -1303,49 +1306,49 @@ class ss_estimation:
 
         Arguments
         ---------
-        est_method: `str` {`gmm`, `negbin`} The estimation method to be used when using the `stochastic` model.
-            * Available options when the `model` is 'ss' include:
-            (2) 'gmm': The new generalized methods of moments from us that is based on master equations, similar to the
-            "moment" model in the excellent scVelo package;
-            (3) 'negbin': The new method from us that models steady state RNA expression as a negative binomial distribution,
-            also built upon on master equations.
-            Note that all those methods require using extreme data points (except negbin, which use all data points) for
-            estimation. Extreme data points are defined as the data from cells whose expression of unspliced / spliced
-            or new / total RNA, etc. are in the top or bottom, 5%, for example. `linear_regression` only considers the mean of
-            RNA species (based on the `deterministic` ordinary different equations) while moment based methods (`gmm`, `negbin`)
-            considers both first moment (mean) and second moment (uncentered variance) of RNA species (based on the `stochastic`
-            master equations).
-            The above method are all (generalized) linear regression based method. In order to return estimated parameters
-            (including RNA half-life), it additionally returns R-squared (either just for extreme data points or all data points)
-            as well as the log-likelihood of the fitting, which will be used for transition matrix and velocity embedding.
-            All `est_method` uses least square to estimate optimal parameters with latin cubic sampler for initial sampling.
-        u: :class:`~numpy.ndarray` or sparse `csr_matrix`
-            A matrix of unspliced mRNA counts. Dimension: genes x cells.
-        s: :class:`~numpy.ndarray` or sparse `csr_matrix`
-            A matrix of spliced mRNA counts. Dimension: genes x cells.
-        us: :class:`~numpy.ndarray` or sparse `csr_matrix`
-            A matrix of unspliced mRNA counts. Dimension: genes x cells.
-        ss: :class:`~numpy.ndarray` or sparse `csr_matrix`
-            A matrix of spliced mRNA counts. Dimension: genes x cells.
-        perc_left: float
-            The percentage of samples included in the linear regression in the left tail. If set to None, then all the left samples are excluded.
-        perc_right: float
-            The percentage of samples included in the linear regression in the right tail. If set to None, then all the samples are included.
-        normalize: bool
-            Whether to first normalize the
+            est_method: `str` {`gmm`, `negbin`} The estimation method to be used when using the `stochastic` model.
+                * Available options when the `model` is 'ss' include:
+                (2) 'gmm': The new generalized methods of moments from us that is based on master equations, similar to the
+                "moment" model in the excellent scVelo package;
+                (3) 'negbin': The new method from us that models steady state RNA expression as a negative binomial distribution,
+                also built upon on master equations.
+                Note that all those methods require using extreme data points (except negbin, which use all data points) for
+                estimation. Extreme data points are defined as the data from cells whose expression of unspliced / spliced
+                or new / total RNA, etc. are in the top or bottom, 5%, for example. `linear_regression` only considers the mean of
+                RNA species (based on the `deterministic` ordinary different equations) while moment based methods (`gmm`, `negbin`)
+                considers both first moment (mean) and second moment (uncentered variance) of RNA species (based on the `stochastic`
+                master equations).
+                The above method are all (generalized) linear regression based method. In order to return estimated parameters
+                (including RNA half-life), it additionally returns R-squared (either just for extreme data points or all data points)
+                as well as the log-likelihood of the fitting, which will be used for transition matrix and velocity embedding.
+                All `est_method` uses least square to estimate optimal parameters with latin cubic sampler for initial sampling.
+            u: :class:`~numpy.ndarray` or sparse `csr_matrix`
+                A matrix of unspliced mRNA counts. Dimension: genes x cells.
+            s: :class:`~numpy.ndarray` or sparse `csr_matrix`
+                A matrix of spliced mRNA counts. Dimension: genes x cells.
+            us: :class:`~numpy.ndarray` or sparse `csr_matrix`
+                A matrix of unspliced mRNA counts. Dimension: genes x cells.
+            ss: :class:`~numpy.ndarray` or sparse `csr_matrix`
+                A matrix of spliced mRNA counts. Dimension: genes x cells.
+            perc_left: float
+                The percentage of samples included in the linear regression in the left tail. If set to None, then all the left samples are excluded.
+            perc_right: float
+                The percentage of samples included in the linear regression in the right tail. If set to None, then all the samples are included.
+            normalize: bool
+                Whether to first normalize the
 
         Returns
         -------
-        k: float
-            The slope of the linear regression model, which is gamma under the steady state assumption.
-        b: float
-            The intercept of the linear regression model.
-        r2: float
-            Coefficient of determination or r square for the extreme data points.
-        r2: float
-            Coefficient of determination or r square for the extreme data points.
-        all_r2: float
-            Coefficient of determination or r square for all data points.
+            k: float
+                The slope of the linear regression model, which is gamma under the steady state assumption.
+            b: float
+                The intercept of the linear regression model.
+            r2: float
+                Coefficient of determination or r square for the extreme data points.
+            r2: float
+                Coefficient of determination or r square for the extreme data points.
+            all_r2: float
+                Coefficient of determination or r square for all data points.
         """
         u = u.A.flatten() if issparse(u) else u.flatten()
         s = s.A.flatten() if issparse(s) else s.flatten()
@@ -1372,23 +1375,23 @@ class ss_estimation:
 
         Arguments
         ---------
-        t: :class:`~numpy.ndarray`
-            A vector of time points.
-        U: :class:`~numpy.ndarray`
-            A matrix of unspliced mRNA counts. Dimension: genes x cells.
-        S: :class:`~numpy.ndarray`
-            A matrix of spliced mRNA counts. Dimension: genes x cells.
+            t: :class:`~numpy.ndarray`
+                A vector of time points.
+            U: :class:`~numpy.ndarray`
+                A matrix of unspliced mRNA counts. Dimension: genes x cells.
+            S: :class:`~numpy.ndarray`
+                A matrix of spliced mRNA counts. Dimension: genes x cells.
 
         Returns
         -------
-        beta: :class:`~numpy.ndarray`
-            A vector of betas for all the genes.
-        gamma: :class:`~numpy.ndarray`
-            A vector of gammas for all the genes.
-        u0: float
-            Initial value of u.
-        s0: float
-            Initial value of s.
+            beta: :class:`~numpy.ndarray`
+                A vector of betas for all the genes.
+            gamma: :class:`~numpy.ndarray`
+                A vector of gammas for all the genes.
+            u0: float
+                Initial value of u.
+            s0: float
+                Initial value of s.
         """
         n = U.shape[0]  # self.get_n_genes(data=U)
         beta = np.zeros(n)
@@ -1408,17 +1411,17 @@ class ss_estimation:
 
         Arguments
         ---------
-        t: :class:`~numpy.ndarray`
-            A vector of time points.
-        L: :class:`~numpy.ndarray`
-            A matrix of labeled mRNA counts. Dimension: genes x cells.
+            t: :class:`~numpy.ndarray`
+                A vector of time points.
+            L: :class:`~numpy.ndarray`
+                A matrix of labeled mRNA counts. Dimension: genes x cells.
 
         Returns
         -------
-        gamma: :class:`~numpy.ndarray`
-            A vector of gammas for all the genes.
-        l0: float
-            The estimated value for the initial spliced, labeled mRNA count.
+            gamma: :class:`~numpy.ndarray`
+                A vector of gammas for all the genes.
+            l0: float
+                The estimated value for the initial spliced, labeled mRNA count.
         """
         n = L.shape[0]  # self.get_n_genes(data=L)
         gamma = np.zeros(n)
@@ -1440,24 +1443,24 @@ class ss_estimation:
         
         This approach assumes the same constant beta or gamma for both steady state or stimulation period.
 
-        Parameters
+        Arguments
         ----------
-        t: `list` or `numpy.ndarray`
-            Time period for stimulation state labeling for each cell.
-        ul:
-            A vector of labeled RNA amount in each cell.
-        beta: `numpy.ndarray`
-            A list of splicing rate for genes.
-        clusters: `list`
-            A list of n clusters, each element is a list of indices of the samples which belong to this cluster.
-        alpha_time_dependent: `bool`
-            Whether or not to model the simulation alpha rate as a time dependent variable.
+            t: `list` or `numpy.ndarray`
+                Time period for stimulation state labeling for each cell.
+            ul:
+                A vector of labeled RNA amount in each cell.
+            beta: `numpy.ndarray`
+                A list of splicing rate for genes.
+            clusters: `list`
+                A list of n clusters, each element is a list of indices of the samples which belong to this cluster.
+            alpha_time_dependent: `bool`
+                Whether or not to model the simulation alpha rate as a time dependent variable.
 
         Returns
         -------
-        alpha_std, alpha_stm: `numpy.ndarray`, `numpy.ndarray`
-            The constant steady state transcription rate (alpha_std) or time-dependent or time-independent (determined by
-            alpha_time_dependent) transcription rate (alpha_stm)
+            alpha_std, alpha_stm: `numpy.ndarray`, `numpy.ndarray`
+                The constant steady state transcription rate (alpha_std) or time-dependent or time-independent (determined by
+                alpha_time_dependent) transcription rate (alpha_stm)
         """
 
         # calculate alpha initial guess:
@@ -1499,19 +1502,19 @@ class ss_estimation:
 
         Arguments
         ---------
-        t: float
-            labelling duration.
-        U: :class:`~numpy.ndarray`
-            A matrix of unspliced mRNA counts. Dimension: genes x cells.
-        beta: :class:`~numpy.ndarray`
-            A vector of betas for all the genes.
-        clusters: list
-            A list of n clusters, each element is a list of indices of the samples which belong to this cluster.
+            t: float
+                labelling duration.
+            U: :class:`~numpy.ndarray`
+                A matrix of unspliced mRNA counts. Dimension: genes x cells.
+            beta: :class:`~numpy.ndarray`
+                A vector of betas for all the genes.
+            clusters: list
+                A list of n clusters, each element is a list of indices of the samples which belong to this cluster.
 
         Returns
         -------
-        alpha: :class:`~numpy.ndarray`
-            A numpy array with the dimension of n_genes x clusters.
+            alpha: :class:`~numpy.ndarray`
+                A numpy array with the dimension of n_genes x clusters.
         """
         n_genes, n_cells = U.shape
         if clusters is None:
@@ -1565,10 +1568,10 @@ class ss_estimation:
 
         Arguments
         ---------
-        name: string
-            The name of the parameter. E.g. 'beta'.
-        value: :class:`~numpy.ndarray`
-            A vector of values for the parameter to be set to.
+            name: string
+                The name of the parameter. E.g. 'beta'.
+            value: :class:`~numpy.ndarray`
+                A vector of values for the parameter to be set to.
         """
         if len(np.shape(value)) == 0:
             value = value * np.ones(self.get_n_genes())
