@@ -11,11 +11,11 @@ from .utils import (
     set_stream_line_alpha,
 )
 from ..tools.dimension_reduction import reduceDimension
-from ..tools.cell_vectors import cell_velocities
+from ..tools.cell_velocities import cell_velocities
 from ..tools.Markov import prepare_velocity_grid_data, velocity_on_grid, grid_velocity_filter
 from ..vectorfield.topography import VectorField
 from ..tools.utils import update_dict
-from ..vectorfield.utils_vecCalc import vecfld_from_adata
+from ..vectorfield.utils import vecfld_from_adata
 
 from .scatters import docstrings
 
@@ -25,7 +25,7 @@ import scipy as sc
 
 # from licpy.lic import runlic
 
-# moran'I on the velocity genes, etc.
+# moran'I on the transition genes, etc.
 
 # cellranger data, velocyto, comparison and phase diagram
 
