@@ -5,32 +5,33 @@ from sklearn.neighbors import NearestNeighbors
 from multiprocessing.dummy import Pool as ThreadPool
 import itertools
 import warnings
-from .utils import (
-    integrate_vf_ivp,
+from ..tools.utils import (
     fetch_states,
     getTseq,
 )
+from .utils import (
+    integrate_vf_ivp,
+)
 from ..vectorfield import vector_field_function
 
 
-def fate(
-    adata,
-    init_cells,
-    init_states=None,
-    basis=None,
-    layer="X",
-    dims=None,
-    genes=None,
-    t_end=None,
-    direction="both",
-    interpolation_num=250,
-    average=False,
-    sampling='arc_length',
-    VecFld_true=None,
-    inverse_transform=False,
-    scale=1,
-    cores=1,
-    **kwargs
+def fate(adata,
+         init_cells,
+         init_states=None,
+         basis=None,
+         layer="X",
+         dims=None,
+         genes=None,
+         t_end=None,
+         direction="both",
+         interpolation_num=250,
+         average=False,
+         sampling='arc_length',
+         VecFld_true=None,
+         inverse_transform=False,
+         scale=1,
+         cores=1,
+         **kwargs
 ):
     """Predict the historical and future cell transcriptomic states over arbitrary time scales.
 
@@ -55,9 +56,11 @@ def fate(
             Which layer of the data will be used for predicting cell fate with the reconstructed vector field function.
             The layer once provided, will override the `basis` argument and then predicting cell fate in high dimensional
             space.
+        dims: `scalar`, `list` or None (default: `None')
+            The dimensions that will be selected for fate prediction.
         genes: `list` or None (default: None)
             The gene names whose gene expression will be used for predicting cell fate. By default (when genes is set to
-            None), the genes used for velocity embedding (var.use_for_velocity) will be used for vector field
+            None), the genes used for velocity embedding (var.use_for_transition) will be used for vector field
             reconstruction. Note that the genes to be used need to have velocity calculated and corresponds to those used
             in the `dyn.tl.VectorField` function.
         t_end: `float` (default None)
@@ -145,7 +148,7 @@ def fate(
         if adata.var.use_for_dynamics.sum() == high_prediction.shape[1]:
             valid_genes = adata.var_names[adata.var.use_for_dynamics]
         else:
-            valid_genes = adata.var_names[adata.var.use_for_velocity]
+            valid_genes = adata.var_names[adata.var.use_for_transition]
 
     elif basis == "umap" and inverse_transform:
         # this requires umap 0.4; reverse project to PCA space.
@@ -165,8 +168,8 @@ def fate(
 
         if adata.var.use_for_dynamics.sum() == high_prediction.shape[1]:
             valid_genes = adata.var_names[adata.var.use_for_dynamics]
-        elif adata.var.use_for_velocity.sum() == high_prediction.shape[1]:
-            valid_genes = adata.var_names[adata.var.use_for_velocity]
+        elif adata.var.use_for_transition.sum() == high_prediction.shape[1]:
+            valid_genes = adata.var_names[adata.var.use_for_transition]
         else:
             raise Exception(
                 "looks like a customized set of genes is used for pca analysis of the adata. "
@@ -259,25 +262,33 @@ def _fate(
         )
     else:
         pool = ThreadPool(cores)
-        res = pool.starmap(integrate_vf_ivp, zip(init_states, itertools.repeat(t_linspace), itertools.repeat(()),
-                                      itertools.repeat(direction), itertools.repeat(VecFld),
-                                      itertools.repeat(interpolation_num), itertools.repeat(False),
-                                      itertools.repeat(True))) # disable tqdm when using multiple cores.
+        res = pool.starmap(integrate_vf_ivp, zip(init_states,
+                                                 itertools.repeat(t_linspace),
+                                                 itertools.repeat(()),
+                                                 itertools.repeat(direction),
+                                                 itertools.repeat(VecFld),
+                                                 itertools.repeat(interpolation_num),
+                                                 itertools.repeat(average),
+                                                 itertools.repeat(sampling),
+                                                 itertools.repeat(False),
+                                                 itertools.repeat(True)
+                                                 )) # disable tqdm when using multiple cores.
         pool.close()
         pool.join()
         t_, prediction_ = zip(*res)
         t, prediction = [i[0] for i in t_], [i[0] for i in prediction_]
-        t, prediction = np.hstack(t), np.hstack(prediction)
+        t_stack, prediction_stack = np.hstack(t), np.hstack(prediction)
         n_cell, n_feature = init_states.shape
+
         if init_states.shape[0] > 1 and average:
-            t_len = int(len(t) / n_cell)
+            t_len = int(len(t_stack) / n_cell)
             avg = np.zeros((n_feature, t_len))
 
             for i in range(t_len):
-                avg[:, i] = np.mean(prediction[:, np.arange(n_cell) * t_len + i], 1)
+                avg[:, i] = np.mean(prediction_stack[:, np.arange(n_cell) * t_len + i], 1)
 
-            prediction = avg
-            t = np.sort(np.unique(t))
+            prediction = [avg]
+            t = [np.sort(np.unique(t))]
 
     return t, prediction
 
@@ -445,7 +456,7 @@ def fate_bias(adata,
                 if hasattr(nbrs, 'query'):
                     knn, _ = nbrs.query(X[knn.flatten(), :], k=30)
                 else:
-                    _, knn = knn, nbrs.kneighbors(X[knn.flatten(), :])
+                   _, knn = nbrs.kneighbors(X[knn.flatten(), :])
 
                 fate_prob = clusters[knn.flatten()].value_counts() / len(knn.flatten())
                 if source_groups is not None:
@@ -457,7 +468,7 @@ def fate_bias(adata,
                 pred_dict[i] = fate_prob
 
                 confidence[i] = 1 - (sum(~ is_dist_larger_than_threshold) + walk_back_steps) / (
-                        len(indices) + walk_back_steps)
+                        len(is_dist_larger_than_threshold) + walk_back_steps)
 
                 break
             else:
