@@ -55,7 +55,7 @@ def szFactor(
             A logic flag to determine whether the gene expression should be rounded into integers.
         method: `str` (default: `mean-geometric-mean-total`)
             The method used to calculate the expected total reads / UMI used in size factor calculation.
-            Only `mean-geometric-mean-total` and `median` are supported. When `median` is used, `locfunc` will be replaced with
+            Only `mean-geometric-mean-total` / `geometric` and `median` are supported. When `median` is used, `locfunc` will be replaced with
             `np.nanmedian`.
         use_all_genes_cells: `bool` (default: `True`)
             A logic flag to determine whether all cells and genes should be used for the size factor calculation.
@@ -124,6 +124,7 @@ def normalize_expr_data(
     relative_expr=True,
     keep_filtered=True,
     recalc_sz=False,
+    sz_method='median',
 ):
     """Normalize the gene expression value for the AnnData object
     This function is partly based on Monocle R package (https://github.com/cole-trapnell-lab/monocle3).
@@ -149,7 +150,10 @@ def normalize_expr_data(
             will be recalculated only for the selected feature genes.
         recalc_sz: `bool` (default: `False`)
             A logic flag to determine whether we need to recalculate size factor based on selected genes before normalization.
-
+        sz_method: `str` (default: `mean-geometric-mean-total`)
+            The method used to calculate the expected total reads / UMI used in size factor calculation.
+            Only `mean-geometric-mean-total` / `geometric` and `median` are supported. When `median` is used, `locfunc` will be replaced with
+            `np.nanmedian`.
     Returns
     -------
         adata: :AnnData
@@ -182,7 +186,7 @@ def normalize_expr_data(
             layers=layers,
             locfunc=np.nanmean,
             round_exprs=True,
-            method="median",
+            method=sz_method,
         )
 
     for layer in layers:
@@ -688,30 +692,30 @@ def SVRs(
         if layer == "raw":
             CM = adata.X.copy() if adata.raw is None else adata.raw
             szfactors = (
-                adata.obs[layer + "_Size_Factor"][:, None]
+                adata.obs[layer + "_Size_Factor"].values[:, None]
                 if adata.raw.X is not None
-                else adata.obs["Size_Factor"][:, None]
+                else adata.obs["Size_Factor"].values[:, None]
             )
         elif layer == "X":
             CM = adata.X.copy()
-            szfactors = adata.obs["Size_Factor"][:, None]
+            szfactors = adata.obs["Size_Factor"].values[:, None]
         elif layer == "protein":
             if "protein" in adata.obsm_keys():
                 CM = adata.obsm["protein"].copy()
-                szfactors = adata.obs[layer + "_Size_Factor"][:, None]
+                szfactors = adata.obs[layer + "_Size_Factor"].values[:, None]
             else:
                 continue
         else:
             CM = adata.layers[layer].copy()
             szfactors = (
-                adata.obs[layer + "_Size_Factor"][:, None]
+                adata.obs[layer + "_Size_Factor"].values[:, None]
                 if layer + "_Size_Factor" in adata.obs.columns
                 else None
             )
 
         if total_szfactor is not None and total_szfactor in adata.obs.keys():
             szfactors = (
-                adata.obs[total_szfactor][:, None]
+                adata.obs[total_szfactor].values[:, None]
                 if total_szfactor in adata.obs.columns
                 else None
             )
@@ -1008,6 +1012,8 @@ def filter_genes(
         & (adata.X.sum(0) >= min_count_s)
     ).flatten()
 
+    # add our filtering for labeling data below
+
     if "spliced" in adata.layers.keys() and (layer == "spliced" or layer == "all"):
         detected_bool = (
             detected_bool
@@ -1150,6 +1156,7 @@ def recipe_monocle(
     genes_to_use=None,
     method="pca",
     num_dim=30,
+    sz_method='median',
     norm_method=None,
     pseudo_expr=1,
     feature_selection="SVR",
@@ -1184,6 +1191,10 @@ def recipe_monocle(
             The linear dimension reduction methods to be used.
         num_dim: `int` (default: `30`)
             The number of linear dimensions reduced to.
+        sz_method: `str` (default: `mean-geometric-mean-total`)
+            The method used to calculate the expected total reads / UMI used in size factor calculation.
+            Only `mean-geometric-mean-total` / `geometric` and `median` are supported. When `median` is used, `locfunc` will be replaced with
+            `np.nanmedian`.
         norm_method: `function` or None (default: function `None`)
             The method to normalize the data. Can be any numpy function or `Freeman_Tukey`. By default, only .X will be
             size normalized and log1p transformed while data in other layers will only be size factor normalized.
@@ -1255,10 +1266,18 @@ def recipe_monocle(
 
     basic_stats(adata)
     has_splicing, has_labeling, _ = detect_datatype(adata)
-    if has_splicing and has_labeling and type(total_layers) != list:
-        total_layers = ['uu', 'ul', 'su', 'sl'] if total_layers else None
-    elif has_labeling and not has_splicing and type(total_layers) != list:
-        total_layers = ['total'] if total_layers else None
+    if has_splicing and has_labeling:
+        layer = ['X', 'uu', 'ul', 'su', 'sl', 'spliced', 'unspliced', 'new', 'total'] if layer is None else layer
+
+        if type(total_layers) != list:
+            total_layers = ['uu', 'ul', 'su', 'sl'] if total_layers else None
+    elif has_labeling and not has_splicing:
+        layer = ['X', 'total', 'new'] if layer is None else layer
+
+        if type(total_layers) != list:
+            total_layers = ['total'] if total_layers else None
+    elif has_splicing and not has_labeling:
+        layer = ['X', 'spliced', 'unspliced'] if layer is None else layer
 
     adata = unique_var_obs_adata(adata)
     adata = layers2csr(adata)
@@ -1331,9 +1350,10 @@ def recipe_monocle(
 
     # calculate sz factor
     if not _szFactor or "Size_Factor" not in adata.obs_keys():
-        adata = szFactor(adata, total_layers=total_layers)
-        if feature_selection == "Dispersion":
-            adata = Dispersion(adata)
+        adata = szFactor(adata, total_layers=total_layers, layers=layer if type(layer) is list else "all")
+
+    if feature_selection.lower() == "dispersion":
+        adata = Dispersion(adata)
 
     # set use_for_pca (use basic_filtered data)
     select_genes_dict = {
@@ -1371,23 +1391,38 @@ def recipe_monocle(
         total_szfactor = "total_Size_Factor" if total_layers is not None else None
         adata = normalize_expr_data(
             adata,
+            layers=layer if type(layer) is list else "all",
             total_szfactor=total_szfactor,
             norm_method=norm_method,
             pseudo_expr=pseudo_expr,
             relative_expr=relative_expr,
             keep_filtered=keep_filtered_genes,
+            sz_method=sz_method,
         )
+    else:
+        layers = get_layer_keys(adata, "all")
+        for layer in layers:
+            adata.layers["X_" + layer] = adata.layers[layer].copy()
+
+        adata.uns["pp_norm_method"] = None
 
     # only use genes pass filter (based on use_for_pca) to perform dimension reduction.
     if layer is None:
         CM = adata.X[:, adata.var.use_for_pca.values]
     else:
-        if layer == "X":
+        if "X" in layer:
             CM = adata.X[:, adata.var.use_for_pca.values]
-        elif layer == "protein":
+        elif "total" in layer:
+            CM = adata.layers["X_total"][:, adata.var.use_for_pca.values]
+        elif "spliced" in layer:
+            CM = adata.layers["X_spliced"][:, adata.var.use_for_pca.values]
+        elif "protein" in layer:
             CM = adata.obsm["X_protein"]
-        else:
+        elif type(layer) is str:
             CM = adata.layers["X_" + layer][:, adata.var.use_for_pca.values]
+        else:
+            raise ValueError(f'your input layer argument should be either a `str` or a list that includes one of `X`, '
+                             f'`total`, `protein` element. `Layer` currently is {layer}.')
 
     cm_genesums = CM.sum(axis=0)
     valid_ind = np.logical_and(np.isfinite(cm_genesums), cm_genesums != 0)
