@@ -3,7 +3,6 @@ import warnings
 from anndata import AnnData
 from scipy.sparse import issparse, csr_matrix, lil_matrix, diags
 from tqdm import tqdm
-from .utils_moments import estimation
 from .utils import get_mapper, elem_prod, inverse_norm
 from .connectivity import mnn, normalize_knn_graph, umap_conn_indices_dist_embedding
 from ..preprocessing.utils import get_layer_keys, allowed_X_layer_names, pca
@@ -751,6 +750,7 @@ class Estimation:
             }
 
     def fit_gene(self, gene_no, n_p0=10):
+        from ..estimation.tsc.utils_moments import estimation
         estm = estimation(list(self.param_ranges.values()))
         if self.data_u is None:
             m = self.data.M[gene_no, :].T
