@@ -2,6 +2,7 @@ from tqdm import tqdm
 import numpy as np
 import pandas as pd
 from scipy import interpolate, stats
+from scipy.spatial.distance import squareform as spsquare
 from scipy.sparse import issparse, csr_matrix
 import scipy.sparse.linalg as splinalg
 from scipy.integrate import odeint
@@ -99,6 +100,14 @@ def isarray(arr):
     return hasattr(arr, '__len__') and (not isinstance(arr, str))
 
 
+def areinstance(arr, dtype, logic_func=all):
+    """
+        Check if elements of an array are all (by default) of 'dtype'.
+    """
+    ret = [isinstance(a, dtype) for a in arr]
+    return logic_func(ret)
+
+
 def closest_cell(coord, cells):
     cells = np.asarray(cells)
     dist_2 = np.sum((cells - coord) ** 2, axis=1)
@@ -195,6 +204,25 @@ def index_condensed_matrix(n, i, j):
     return int(i * (n - (i + 3) * 0.5) + j - 1)
 
 
+def condensed_idx_to_squareform_idx(arr_len, i):
+    n = int((1 + np.sqrt(1 + 8 * arr_len)) / 2)
+    fr = lambda x: int(x*(n-(x+3)*0.5) + n - 1)
+    for x in range(n):
+        d = fr(x) - (i+1)
+        if d>=0:
+            break
+    y = n-d-1
+    return x, y
+
+
+def squareform(arr, antisym=False, **kwargs):
+    M = spsquare(arr, **kwargs)
+    if antisym:
+        tril_idx = np.tril_indices_from(M, k=-1)
+        M[tril_idx] = -M[tril_idx]
+    return M
+
+
 def moms2var(m1, m2):
     var = m2 - elem_prod(m1, m1)
     return var
@@ -329,21 +357,6 @@ def inverse_norm(adata, layer_x):
 
     return layer_x
 
-
-# ---------------------------------------------------------------------------------------------------
-# neighbors related:
-def get_conn_dist_graph(knn, distances):
-    n_obs, n_neighbors = knn.shape
-    distances = csr_matrix((distances.flatten(), (np.repeat(np.arange(n_obs), n_neighbors), knn.flatten())),
-                           shape=(n_obs, n_obs))
-    connectivities = distances.copy()
-    connectivities.data[connectivities.data > 0] = 1
-
-    distances.eliminate_zeros()
-    connectivities.eliminate_zeros()
-
-    return distances, connectivities
-
 # ---------------------------------------------------------------------------------------------------
 # dynamics related:
 def one_shot_gamma_alpha(k, t, l):
@@ -479,7 +492,7 @@ def get_data_for_kin_params_estimation(
         S = log_unnormalized_data(raw, log_unnormalized)
 
     # labeling without splicing
-    if (
+    if not has_splicing and (
         ("X_new" in subset_adata.layers.keys() and not use_moments)
         or (mapper["X_new"] in subset_adata.layers.keys() and use_moments)
     ):  # run new / total ratio (NTR)
@@ -499,7 +512,8 @@ def get_data_for_kin_params_estimation(
             if use_moments
             else subset_adata.layers["X_new"].T
         )
-    elif "new" in subset_adata.layers.keys():
+
+    elif not has_splicing and "new" in subset_adata.layers.keys():
         has_labeling, assumption_mRNA = (
             True,
             "ss" if NTR_vel else 'kinetic',
@@ -519,7 +533,7 @@ def get_data_for_kin_params_estimation(
         Ul = raw
 
     # splicing data
-    if (
+    if not has_labeling and (
         ("X_unspliced" in subset_adata.layers.keys() and not use_moments)
         or (mapper["X_unspliced"] in subset_adata.layers.keys() and use_moments)
     ):
@@ -530,7 +544,7 @@ def get_data_for_kin_params_estimation(
             if use_moments
             else subset_adata.layers["X_unspliced"].T
         )
-    elif "unspliced" in subset_adata.layers.keys():
+    elif not has_labeling and "unspliced" in subset_adata.layers.keys():
         has_splicing, assumption_mRNA = True, "kinetic" \
             if tkey in subset_adata.obs.columns else 'ss'
         raw, raw_unspliced = (
@@ -542,7 +556,7 @@ def get_data_for_kin_params_estimation(
         else:
             raw = np.log(raw + 1) if log_unnormalized else raw
         U = raw
-    if (
+    if not has_labeling and (
         ("X_spliced" in subset_adata.layers.keys() and not use_moments)
         or (mapper["X_spliced"] in subset_adata.layers.keys() and use_moments)
     ):
@@ -551,7 +565,7 @@ def get_data_for_kin_params_estimation(
             if use_moments
             else subset_adata.layers["X_spliced"].T
         )
-    elif "spliced" in subset_adata.layers.keys():
+    elif not has_labeling and "spliced" in subset_adata.layers.keys():
         raw, raw_spliced = (
             subset_adata.layers["spliced"].T,
             subset_adata.layers["spliced"].T,
@@ -562,6 +576,7 @@ def get_data_for_kin_params_estimation(
             raw = np.log(raw + 1) if log_unnormalized else raw
         S = raw
 
+    # protein
     ind_for_proteins = None
     if (
         ("X_protein" in subset_adata.obsm.keys() and not use_moments)
@@ -587,8 +602,8 @@ def get_data_for_kin_params_estimation(
             ind_for_proteins = [
                 np.where(subset_adata.var.index == i)[0][0] for i in protein_names
             ]
-            subset_adata.var["is_protein_velocity_genes"] = False
-            subset_adata.var.loc[ind_for_proteins, "is_protein_velocity_genes"] = True
+            subset_adata.var["is_protein_dynamics_genes"] = False
+            subset_adata.var.loc[ind_for_proteins, "is_protein_dynamics_genes"] = True
 
     experiment_type = "conventional"
 
@@ -655,6 +670,8 @@ def set_velocity(
     adata,
     vel_U,
     vel_S,
+    vel_N,
+    vel_T,
     vel_P,
     _group,
     cur_grp,
@@ -673,6 +690,16 @@ def set_velocity(
             adata.layers["velocity_S"] = csr_matrix((adata.shape), dtype=np.float64)
         vel_S = vel_S.T.tocsr() if issparse(vel_S) else csr_matrix(vel_S, dtype=np.float64).T
         adata.layers["velocity_S"][cur_cells_ind, valid_ind_] = vel_S
+    if type(vel_N) is not float:
+        if cur_grp == _group[0]:
+            adata.layers["velocity_N"] = csr_matrix((adata.shape), dtype=np.float64)
+        vel_N = vel_N.T.tocsr() if issparse(vel_N) else csr_matrix(vel_N, dtype=np.float64).T
+        adata.layers["velocity_N"][cur_cells_ind, valid_ind_] = vel_N
+    if type(vel_T) is not float:
+        if cur_grp == _group[0]:
+            adata.layers["velocity_T"] = csr_matrix((adata.shape), dtype=np.float64)
+        vel_T = vel_T.T.tocsr() if issparse(vel_T) else csr_matrix(vel_T, dtype=np.float64).T
+        adata.layers["velocity_T"][cur_cells_ind, valid_ind_] = vel_T
     if type(vel_P) is not float:
         if cur_grp == _group[0]:
             adata.obsm["velocity_P"] = csr_matrix(
@@ -1122,7 +1149,7 @@ def get_group_params_indices(adata, param_name):
     return adata.var.columns.str.endswith(param_name)
 
 
-def set_velocity_genes(
+def set_transition_genes(
     adata,
     vkey="velocity_S",
     min_r2=0.01,
@@ -1130,6 +1157,7 @@ def set_velocity_genes(
     min_gamma=0.01,
     min_delta=0.01,
     use_for_dynamics=True,
+    store_key='use_for_transition'
 ):
     layer = vkey.split("_")[1]
 
@@ -1147,7 +1175,7 @@ def set_velocity_genes(
         if 'alpha_r2' not in adata.var.columns: adata.var['alpha_r2'] = None
         if np.all(adata.var.alpha_r2.values == None):
             adata.var.alpha_r2 = 1
-        adata.var["use_for_velocity"] = (
+        adata.var[store_key] = (
             (adata.var.alpha > min_alpha)
             & (adata.var.alpha_r2 > min_r2)
             & adata.var.use_for_dynamics
@@ -1166,7 +1194,7 @@ def set_velocity_genes(
 
         if 'gamma_r2' not in adata.var.columns: adata.var['gamma_r2'] = None
         if np.all(adata.var.gamma_r2.values == None): adata.var.gamma_r2 = 1
-        adata.var["use_for_velocity"] = (
+        adata.var[store_key] = (
             (adata.var.gamma > min_gamma)
             & (adata.var.gamma_r2 > min_r2)
             & adata.var.use_for_dynamics
@@ -1186,7 +1214,7 @@ def set_velocity_genes(
         if 'delta_r2' not in adata.var.columns: adata.var['delta_r2'] = None
         if np.all(adata.var.delta_r2.values == None):
             adata.var.delta_r2 = 1
-        adata.var["use_for_velocity"] = (
+        adata.var[store_key] = (
             (adata.var.delta > min_delta)
             & (adata.var.delta_r2 > min_r2)
             & adata.var.use_for_dynamics
@@ -1249,29 +1277,45 @@ def get_ekey_vkey_from_adata(adata):
                     "The input data you have is not normalized or normalized + smoothed!"
                 )
 
-            if experiment_type == "kin":
+            if experiment_type.lower() == "kin":
                 ekey, vkey, layer = (
-                    (mapper["X_total"] if NTR else mapper["X_spliced"], "velocity_S", ("X_total" if NTR else "X_spliced"))
+                    (mapper["X_total"] if NTR else mapper["X_spliced"],
+                     "velocity_T" if NTR else "velocity_S",
+                     ("X_total" if NTR else "X_spliced"))
                     if use_smoothed
-                    else ("X_total" if NTR else "X_spliced", "velocity_S", "X_total" if NTR else "X_spliced")
+                    else ("X_total" if NTR else "X_spliced",
+                          "velocity_T" if NTR else "velocity_S",
+                          "X_total" if NTR else "X_spliced")
                 )
-            elif experiment_type == "deg":
+            elif experiment_type.lower() == "deg":
                 ekey, vkey, layer = (
-                    (mapper["X_total"] if NTR else mapper["X_spliced"], "velocity_S", ("X_total" if NTR else "X_spliced"))
+                    (mapper["X_total"] if NTR else mapper["X_spliced"],
+                     "velocity_T" if NTR else "velocity_S",
+                     ("X_total" if NTR else "X_spliced"))
                     if use_smoothed
-                    else ("X_total" if NTR else "X_spliced", "velocity_S", "X_total" if NTR else "X_spliced")
+                    else ("X_total" if NTR else "X_spliced",
+                          "velocity_T" if NTR else "velocity_S",
+                          "X_total" if NTR else "X_spliced")
                 )
-            elif experiment_type == "one_shot":
+            elif experiment_type.lower() in ["one_shot", "one-shot"]:
                 ekey, vkey, layer = (
-                    (mapper["X_total"] if NTR else mapper["X_spliced"], "velocity_S", ("X_total" if NTR else "X_spliced"))
+                    (mapper["X_total"] if NTR else mapper["X_spliced"],
+                     "velocity_T" if NTR else "velocity_S",
+                     ("X_total" if NTR else "X_spliced"))
                     if use_smoothed
-                    else ("X_total" if NTR else "X_spliced", "velocity_S", "X_total" if NTR else "X_spliced")
+                    else ("X_total" if NTR else "X_spliced",
+                          "velocity_T" if NTR else "velocity_S",
+                          "X_total" if NTR else "X_spliced")
                 )
-            elif experiment_type == "mix_std_stm":
+            elif experiment_type.lower() == "mix_std_stm":
                 ekey, vkey, layer = (
-                    (mapper["X_total"] if NTR else mapper["X_spliced"], "velocity_S", ("X_total" if NTR else "X_spliced"))
+                    (mapper["X_total"] if NTR else mapper["X_spliced"],
+                     "velocity_T" if NTR else "velocity_S",
+                     ("X_total" if NTR else "X_spliced"))
                     if use_smoothed
-                    else ("X_total" if NTR else "X_spliced", "velocity_S", "X_total" if NTR else "X_spliced")
+                    else ("X_total" if NTR else "X_spliced",
+                          "velocity_T" if NTR else "velocity_S",
+                          "X_total" if NTR else "X_spliced")
                 )
         else:
             if not (("X_unspliced" in adata.layers.keys()) or (
@@ -1293,27 +1337,27 @@ def get_ekey_vkey_from_adata(adata):
             # we may also create M_U, M_S layers?
             if experiment_type == "kin":
                 ekey, vkey, layer = (
-                    (mapper["X_total"], "velocity_S", "X_total")
+                    (mapper["X_total"], "velocity_T", "X_total")
                     if use_smoothed
-                    else ("X_total", "velocity_S", "X_total")
+                    else ("X_total", "velocity_T", "X_total")
                 )
             elif experiment_type == "deg":
                 ekey, vkey, layer = (
-                    (mapper["X_total"], "velocity_S", "X_total")
+                    (mapper["X_total"], "velocity_T", "X_total")
                     if use_smoothed
-                    else ("X_total", "velocity_S", "X_total")
+                    else ("X_total", "velocity_T", "X_total")
                 )
             elif experiment_type == "one-shot" or experiment_type == "one_shot":
                 ekey, vkey, layer = (
-                    (mapper["X_total"], "velocity_S", "X_total")
+                    (mapper["X_total"], "velocity_T", "X_total")
                     if use_smoothed
-                    else ("X_total", "velocity_S", "X_total")
+                    else ("X_total", "velocity_T", "X_total")
                 )
             elif experiment_type == "mix_std_stm":
                 ekey, vkey, layer = (
-                    (mapper["X_total"], "velocity_S", "X_total")
+                    (mapper["X_total"], "velocity_T", "X_total")
                     if use_smoothed
-                    else ("X_total", "velocity_S", "X_total")
+                    else ("X_total", "velocity_T", "X_total")
                 )
 
         else:
@@ -1366,17 +1410,6 @@ def split_velocity_graph(G, neg_cells_trick=True):
     else:
         return G
 
-# ---------------------------------------------------------------------------------------------------
-# dimension reduction related
-
-def build_distance_graph(knn_indices, knn_dists):
-    knn_dists = csr_matrix((knn_dists.flatten(),
-                            (np.repeat(knn_indices[:, 0], knn_indices.shape[1]),
-                             knn_indices.flatten())))
-    knn_dists.eliminate_zeros()
-
-    return knn_dists
-
 
 # ---------------------------------------------------------------------------------------------------
 # vector field related
@@ -1517,3 +1550,96 @@ def integrate_vf(
 
     return t, Y
 
+
+# ---------------------------------------------------------------------------------------------------
+# fetch states
+def fetch_states(adata, init_states, init_cells, basis, layer, average, t_end):
+    if basis is not None:
+        vf_key = "VecFld_" + basis
+    else:
+        vf_key = "VecFld"
+    VecFld = adata.uns[vf_key]['VecFld']
+    X = VecFld['X']
+    valid_genes = None
+
+    if init_states is None and init_cells is None:
+        raise Exception("Either init_state or init_cells should be provided.")
+    elif init_states is None and init_cells is not None:
+        if type(init_cells) == str:
+            init_cells = [init_cells]
+        intersect_cell_names = sorted(
+            set(init_cells).intersection(adata.obs_names),
+            key=lambda x: list(init_cells).index(x),
+        )
+        _cell_names = (
+            init_cells if len(intersect_cell_names) == 0 else intersect_cell_names
+        )
+
+        if basis is not None:
+            init_states = adata[_cell_names].obsm["X_" + basis].copy()
+            if len(_cell_names) == 1:
+                init_states = init_states.reshape((1, -1))
+            VecFld = adata.uns["VecFld_" + basis]["VecFld"]
+            X = adata.obsm["X_" + basis]
+
+            valid_genes = [
+                basis + "_" + str(i) for i in np.arange(init_states.shape[1])
+            ]
+        else:
+            # valid_genes = list(set(genes).intersection(adata.var_names[adata.var.use_for_transition]) if genes is not None \
+            #     else adata.var_names[adata.var.use_for_transition]
+            # ----------- enable the function to only only a subset genes -----------
+
+            vf_key = "VecFld" if layer == "X" else "VecFld_" + layer
+            valid_genes = adata.uns[vf_key]["genes"]
+            init_states = (
+                adata[_cell_names, :][:, valid_genes].X
+                if layer == "X"
+                else log1p_(adata, adata[_cell_names, :][:, valid_genes].layers[layer])
+            )
+            if issparse(init_states):
+                init_states = init_states.A
+            if len(_cell_names) == 1:
+                init_states = init_states.reshape((1, -1))
+
+            if layer == "X":
+                VecFld = adata.uns["VecFld"]["VecFld"]
+                X = adata[:, valid_genes].X
+            else:
+                VecFld = adata.uns["VecFld_" + layer]["VecFld"]
+                X = log1p_(adata, adata[:, valid_genes].layers[layer])
+
+    if init_states.shape[0] > 1 and average in ["origin", 'trajectory', True]:
+        init_states = init_states.mean(0).reshape((1, -1))
+
+    if t_end is None:
+        t_end = getTend(X, VecFld["V"])
+
+    if issparse(init_states):
+        init_states = init_states.A
+
+    return init_states, VecFld, t_end, valid_genes
+
+
+def getTend(X, V):
+    xmin, xmax = X.min(0), X.max(0)
+    V_abs = np.abs(V)
+    t_end = np.max(xmax - xmin) / np.percentile(V_abs[V_abs > 0], 1)
+
+    return t_end
+
+
+def getTseq(init_states, t_end, step_size=None):
+    if step_size is None:
+        max_steps = (
+            int(max(7 / (init_states.shape[1] / 300), 4))
+            if init_states.shape[1] > 300
+            else 7
+        )
+        t_linspace = np.linspace(
+            0, t_end, 10 ** (np.min([int(np.log10(t_end)), max_steps]))
+        )
+    else:
+        t_linspace = np.arange(0, t_end + step_size, step_size)
+
+    return t_linspace
