@@ -6,12 +6,13 @@ from .scVectorField import (
     graphize_vecfld,
     vectorfield
 )  # , evaluate, con_K_div_cur_free
-from .utils_vecCalc import (
+from .utils import (
     vector_field_function,
 )
 from .topography import FixedPoints, VectorField2D, topography, VectorField
-from .cell_accelerations import cell_accelerations
+from .cell_vectors import cell_accelerations, cell_curvatures
 from .vector_calculus import (
+    velocities,
     speed,
     jacobian,
     curl,
@@ -34,6 +35,7 @@ from .scPotential import (
     DiffusionMatrix,
     action,
     Potential,
+    Pot
 )  # , vector_field_function
 from .Bhattacharya import path_integral, alignment
 from .Wang import Wang_action, Wang_LAP, transition_rate, MFPT
